@@ -29,8 +29,8 @@ Released under the MIT licence.
 __author__ = "Marius Gedminas (marius@gedmin.as)"
 __copyright__ = "Copyright (c) 2008-2014 Marius Gedminas"
 __license__ = "MIT"
-__version__ = "1.8.0"
-__date__ = "2014-02-13"
+__version__ = "1.8.1"
+__date__ = "2014-05-15"
 
 
 import codecs
@@ -588,7 +588,7 @@ def show_graph(objs, edge_func, swap_source_target,
         fd, dot_filename = tempfile.mkstemp(prefix='objgraph-',
                                             suffix='.dot', text=True)
         f = os.fdopen(fd, "w")
-        if f.encoding:
+        if getattr(f, 'encoding', None):
             # Python 3 will wrap the file in the user's preferred encoding
             # Re-wrap it for utf-8
             import io
@@ -604,7 +604,9 @@ def show_graph(objs, edge_func, swap_source_target,
     ignore.add(id(depth))
     ignore.add(id(ignore))
     ignore.add(id(sys._getframe()))  # this function
+    ignore.add(id(sys._getframe().f_locals))
     ignore.add(id(sys._getframe(1))) # show_refs/show_backrefs, most likely
+    ignore.add(id(sys._getframe(1).f_locals))
     for obj in objs:
         f.write('  %s[fontcolor=red];\n' % (obj_node_id(obj)))
         depth[id(obj)] = 0
@@ -764,7 +766,7 @@ def short_repr(obj):
                 return obj.__func__.__name__ + ' (bound)'
             else:
                 return obj.__func__.__name__
-        except AttributeError:
+        except AttributeError:  # pragma: nocover
             # Python < 2.6 compatibility
             if obj.im_self is not None:
                 return obj.im_func.__name__ + ' (bound)'
@@ -805,7 +807,7 @@ def edge_label(source, target, shortnames=True):
                 return ' [label="__self__",weight=10]'
             if target is source.__func__:
                 return ' [label="__func__",weight=10]'
-        except AttributeError:
+        except AttributeError:  # pragma: nocover
             # Python < 2.6 compatibility
             if target is source.im_self:
                 return ' [label="im_self",weight=10]'
